@@ -78,7 +78,8 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     QGroupBox* textGroup = new QGroupBox(i18nc("@title:group", "Alarm Text"), this);
     topLayout->addWidget(textGroup);
     QGridLayout* grid = new QGridLayout(textGroup);
-    grid->setMargin(style()->pixelMetric(QStyle::PM_DefaultChildMargin));
+    int dcm = style()->pixelMetric(QStyle::PM_DefaultChildMargin);
+    grid->setContentsMargins(dcm, dcm, dcm, dcm);
     grid->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     QLabel* label = new QLabel(i18nc("@label:textbox", "Prefix:"), textGroup);
     label->setFixedSize(label->sizeHint());
@@ -107,7 +108,7 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     QGroupBox* group = new QGroupBox(i18nc("@title:group", "Select Birthdays"), this);
     topLayout->addWidget(group);
     QVBoxLayout* layout = new QVBoxLayout(group);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 
     // Start Akonadi server as we need it for the birthday model to access contacts information
     Akonadi::ControlGui::start();
@@ -132,7 +133,7 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     mListView->setModel(mBirthdaySortModel);
     mListView->setRootIsDecorated(false);    // don't show expander icons
     mListView->setSortingEnabled(true);
-    mListView->sortByColumn(BirthdayModel::NameColumn);
+    mListView->sortByColumn(BirthdayModel::NameColumn, mListView->header()->sortIndicatorOrder());
     mListView->setAllColumnsShowFocus(true);
     mListView->setSelectionMode(QAbstractItemView::ExtendedSelection);
     mListView->setSelectionBehavior(QAbstractItemView::SelectRows);
@@ -150,12 +151,12 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     group = new QGroupBox(i18nc("@title:group", "Alarm Configuration"), this);
     topLayout->addWidget(group);
     QVBoxLayout* groupLayout = new QVBoxLayout(group);
-    groupLayout->setMargin(style()->pixelMetric(QStyle::PM_DefaultChildMargin));
+    groupLayout->setContentsMargins(dcm, dcm, dcm, dcm);
     groupLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
 
     // Sound checkbox and file selector
     QHBoxLayout* hlayout = new QHBoxLayout();
-    hlayout->setMargin(0);
+    hlayout->setContentsMargins(0, 0, 0, 0);
     groupLayout->addLayout(hlayout);
     mSoundPicker = new SoundPicker(group);
     mSoundPicker->setFixedSize(mSoundPicker->sizeHint());
@@ -182,7 +183,7 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 
     // Acknowledgement confirmation required - default = no confirmation
     hlayout = new QHBoxLayout();
-    hlayout->setMargin(0);
+    hlayout->setContentsMargins(0, 0, 0, 0);
     hlayout->setSpacing(2 * style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     groupLayout->addLayout(hlayout);
     mConfirmAck = EditDisplayAlarmDlg::createConfirmAckCheckbox(group);
@@ -201,7 +202,7 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
 
     // Late display checkbox - default = allow late display
     hlayout = new QHBoxLayout();
-    hlayout->setMargin(0);
+    hlayout->setContentsMargins(0, 0, 0, 0);
     hlayout->setSpacing(2 * style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     groupLayout->addLayout(hlayout);
     mLateCancel = new LateCancelSelector(false, group);
@@ -227,7 +228,7 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
                       Preferences::defaultSoundVolume(), -1, 0, Preferences::defaultSoundRepeat());
     if (mSpecialActionsButton)
     {
-        KAEvent::ExtraActionOptions opts(0);
+        KAEvent::ExtraActionOptions opts{};
         if (Preferences::defaultExecPreActionOnDeferral())
             opts |= KAEvent::ExecPreActOnDeferral;
         if (Preferences::defaultCancelOnPreActionError())
@@ -252,7 +253,8 @@ BirthdayDlg::BirthdayDlg(QWidget* parent)
     KStandardAction::selectAll(mListView, SLOT(selectAll()), actions);
     KStandardAction::deselect(mListView, SLOT(clearSelection()), actions);
     actions->addAssociatedWidget(mListView);
-    foreach (QAction* action, actions->actions())
+    const auto lstActions = actions->actions();
+    for (QAction* action : lstActions)
         action->setShortcutContext(Qt::WidgetWithChildrenShortcut);
 
     mButtonBox->button(QDialogButtonBox::Ok)->setEnabled(false); // only enable OK button when something is selected
