@@ -27,8 +27,8 @@
 #include <AkonadiCore/itemfetchjob.h>
 #include <AkonadiCore/itemfetchscope.h>
 #include <AkonadiCore/itemdeletejob.h>
-#include <KCalCore/Event>
-using namespace KCalCore;
+#include <KCalendarCore/Event>
+using namespace KCalendarCore;
 
 #include <QTimer>
 #include "kalarm_debug.h"
